@@ -1,7 +1,6 @@
 from dt.ext.aws_s3 import get_lastest_file
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
-import ipdb
 from ..core.version import get_version
 from pprint import pprint as pp
 import os
@@ -461,9 +460,10 @@ class Base(Controller):
             if self.app.pargs.target == '-1':
                 get_drives(self.app.pargs.target, show_n=show_n, metadata_file=metadata_file, filter=filter)
             else:
-                num_segments = self.app.pargs.__dict__.get('n') or self.app.pargs.__dict__.get('num_segments')
+                # TODO: potentially removed
+                # num_segments = self.app.pargs.__dict__.get('n') or self.app.pargs.__dict__.get('num_segments')
                 get_drives(self.app.pargs.target, show_n=show_n, metadata_file=metadata_file, 
-                            num_segments = num_segments, filter=int(filter))
+                            filter=int(filter))
 
         if self.app.pargs.action == 'pull':
             from ..ext.aws_s3 import pull_latest
